@@ -342,8 +342,8 @@ class OutputManager(object):
         if log.handlers and isinstance(log.handlers[0], logging.FileHandler):
             log.handlers[0].close()
             # no logging after this point
-            os.rename(log.handlers[0].baseFilename,
-                      os.path.join(output_root, name, 'hotsos.log'))
+            shutil.move(log.handlers[0].baseFilename,
+                        os.path.join(output_root, name, 'hotsos.log'))
 
         return output_root
 
